@@ -6,29 +6,11 @@
  * This file defines all of the types common to the Linux-PAM library
  * applications and modules.
  *
- * Note, the copyright information is at end of file.
+ * Note, the copyright+license information is at end of file.
  *
  * Created: 1996/3/5 by AGM
  *
- * $Log: _pam_types.h,v $
- * Revision 1.10  1997/04/05 06:52:50  morgan
- * added HAVE_PAM_FAIL_DELAY if the library contains this function.
- * useful for conditional compilation
- *
- * Revision 1.9  1997/01/04 20:13:40  morgan
- * remove PAM_FAIL_NOW, moved PAM_DATA_xx to the modules file where
- * it belongs
- *
- * Revision 1.8  1996/12/01 03:24:00  morgan
- * added environment functions
- *
- * Revision 1.7  1996/11/10 19:54:58  morgan
- * added some optional memory debugging.
- * added some non-Linux-PAM compatability code.. [header file inclusion]
- *
- * Revision 1.6  1996/07/07 23:54:56  morgan
- * added support for pam_fail_delay
- *
+ * $Log$
  */
 
 #ifndef _SECURITY__PAM_TYPES_H
@@ -98,11 +80,18 @@ typedef struct pam_handle pam_handle_t;
 #define PAM_AUTHTOK_EXPIRED  27 /* user's authentication token has expired */
 #define PAM_MODULE_UNKNOWN   28 /* module is not known */
 
+#define PAM_BAD_ITEM         29 /* Bad item passed to pam_*_item() */
+#define PAM_CONV_AGAIN       30 /* conversation function is event driven
+				     and data is not available yet */
+#define PAM_INCOMPLETE       31 /* please call this function again to
+				   complete authentication stack. Before
+				   calling again, verify that conversation
+				   is completed */
+
 /* Add new #define's here */
 
-#define PAM_BAD_ITEM       29   /* Bad item passed to pam_*_item() */
+#define _PAM_RETURN_VALUES 32   /* this is the number of return values */
 
-#define _PAM_RETURN_VALUES 30   /* this is the number of return values */
 
 /* ---------------------- The Linux-PAM flags -------------------- */
 
@@ -140,27 +129,29 @@ typedef struct pam_handle pam_handle_t;
 
 /* these defines are used by pam_set_item() and pam_get_item() */
 
-#define PAM_SERVICE	1	/* The service name */
-#define PAM_USER        2	/* The user name */
-#define PAM_TTY         3	/* The tty name */
-#define PAM_RHOST       4	/* The remote host name */
-#define PAM_CONV        5	/* The pam_conv structure */
+#define PAM_SERVICE	   1	/* The service name */
+#define PAM_USER           2	/* The user name */
+#define PAM_TTY            3	/* The tty name */
+#define PAM_RHOST          4	/* The remote host name */
+#define PAM_CONV           5	/* The pam_conv structure */
 
 /* missing entries found in <security/pam_modules.h> for modules only! */
 
-#define PAM_RUSER       8	/* The remote user name */
-#define PAM_USER_PROMPT 9       /* the prompt for getting a username */
-
+#define PAM_RUSER          8	/* The remote user name */
+#define PAM_USER_PROMPT    9    /* the prompt for getting a username */
+#define PAM_FAIL_DELAY     10   /* app supplied function to override failure
+				   delays */
+#define PAM_LOG_STATE      11   /* ident, facility etc. logging info */
 
 /* ---------- Common Linux-PAM application/module PI ----------- */
 
 extern int pam_set_item(pam_handle_t *pamh, int item_type, const void *item);
-extern int pam_get_item(const pam_handle_t *pamh, int item_type
-			, const void **item);
+extern int pam_get_item(const pam_handle_t *pamh, int item_type,
+			const void **item);
 extern const char *pam_strerror(pam_handle_t *pamh, int errnum);
 
 extern int pam_putenv(pam_handle_t *pamh, const char *name_value);
-extern const char * pam_getenv(pam_handle_t *pamh, const char *name);
+extern const char *pam_getenv(pam_handle_t *pamh, const char *name);
 extern char **pam_getenvlist(pam_handle_t *pamh);
 
 /* ---------- Common Linux-PAM application/module PI ----------- */
@@ -181,11 +172,56 @@ extern char **pam_getenvlist(pam_handle_t *pamh);
  * that primes the libpam library to delay when a stacked set of
  * modules results in a failure. In the case of PAM_SUCCESS this delay
  * is ignored.
+ *
+ * Note, the pam_[gs]et_item(... PAM_FAIL_DELAY ...) can be used to set
+ * a function pointer which can override the default fail-delay behavior.
+ * This item was added to accommodate event driven programs that need to
+ * manage delays more carefully.  The function prototype for this data
+ * item is
+ *           void (*fail_delay)(int status, unsigned int delay);
  */
 
 #define HAVE_PAM_FAIL_DELAY
 extern int pam_fail_delay(pam_handle_t *pamh, unsigned int musec_delay);
 
+/*
+ * the standard libc interface for syslog suffers from some problems.
+ * The first is that it is not thread safe.  It is also three functions
+ * where PAM only really needs a "log this" function.  It also does
+ * not provide modules and applications with information about whether
+ * the log is currently open or not etc...  All of these things mean
+ * that we need to centralize PAM's logging facility.  These two functions
+ * provide this centralization.  They are, however, just a gateway to
+ * libc's openlog/syslog/closelog functions.  Please note, your apps/modules
+ * will likely start to segfault if you do not use this function for
+ * system logging.
+ */
+
+struct pam_log_state {
+    char *ident;
+    int option;
+    int facility;
+};
+
+#ifndef LOG_ERR
+# include <syslog.h>      /* this is a sad HACK. But we need LOG_CRIT etc.. */
+#endif
+
+#define PAM_LOG_STATE_IDENT    "PAM"
+#define PAM_LOG_STATE_OPTION   LOG_PID
+#define PAM_LOG_STATE_FACILITY LOG_AUTHPRIV
+
+#ifndef va_start
+# include <stdarg.h>
+#endif
+
+#define HAVE_PAM_SYSTEM_LOG
+extern void pam_vsystem_log(const pam_handle_t *pamh,
+			    const struct pam_log_state *log_state,
+			    int priority, const char *format, va_list args);
+extern void pam_system_log(const pam_handle_t *pamh,
+			   const struct pam_log_state *log_state, 
+			   int priority, const char *format, ... );
 
 #ifdef MEMORY_DEBUG
 /*
@@ -217,8 +253,8 @@ extern int pam_fail_delay(pam_handle_t *pamh, unsigned int musec_delay);
    is intercepted by the server and unpacked in preparation for the
    module */
 
-#define PAM_BINARY_MSG         6
-#define PAM_BINARY_PROMPT      7
+#define PAM_BINARY_MSG          6
+#define PAM_BINARY_PROMPT       7
 
 /* maximum size of messages/responses etc.. (these are mostly
    arbitrary so Linux-PAM should handle longer values). */
@@ -236,19 +272,20 @@ struct pam_message {
     const char *msg;
 };
 
-/* if the pam_message.msg_style = PAM_BINARY_MSG or PAM_BINARY_PROMPT
+/* if the pam_message.msg_style = PAM_BINARY_PROMPT
    the 'pam_message.msg' is a pointer to a 'const *' for the following
    pseudo-structure.  When used with a PAM_BINARY_PROMPT, the returned
    pam_response.resp pointer points to an object with the following
    structure:
 
    struct {
-       int length;
+       u32 length;                         #  network byte order
        unsigned char data[length];
    };
 
    The 'libpam_client' library is designed around this flavor of
-   message and should be used to handle this flavor of msg_style. */
+   message and should be used to handle this flavor of msg_style.
+   */
 
 /* Used to return the user's response to the PAM library.  This
    structure is allocated by the application program, and free()'d by
