@@ -1,7 +1,7 @@
 /*
  * <security/pam_modules.h>
  * 
- * $Id: pam_modules.h,v 1.8 1997/01/04 20:14:42 morgan Exp $
+ * $Id: pam_modules.h,v 1.8 1997/01/04 20:14:42 morgan Exp morgan $
  *
  * This header file documents the PAM SPI --- that is, interface
  * between the PAM library and a PAM service library which is called
@@ -147,9 +147,13 @@ PAM_EXTERN int pam_sm_chauthtok(pam_handle_t *pamh, int flags,
 
 #define PAM_DATA_REPLACE   0x20000000     /* used when replacing a data item */
 
-/* Copyright (C) Theodore Ts'o, 1996.  All rights reserved.
-   Copyright (C) Andrew Morgan, 1996.
+/* take care of any compatibility issues */
+#include <security/_pam_compat.h>
 
+/* Copyright (C) Theodore Ts'o, 1996.
+ * Copyright (C) Andrew Morgan, 1996-8.
+ *                                                All rights reserved.
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
