@@ -20,19 +20,23 @@ int pam_authenticate(pam_handle_t *pamh, int flags)
 
     D(("pam_authenticate called"));
 
-    _pam_sanitize(pamh);
-
-    _pam_start_timer(pamh);    /* we try to make the time for a failure
-				  independent of the time it takes to
-				  fail */
+    if (pamh->former.choice == PAM_NOT_STACKED) {
+	_pam_sanitize(pamh);
+	_pam_start_timer(pamh);    /* we try to make the time for a failure
+				      independent of the time it takes to
+				      fail */
+    }
 
     IF_NO_PAMH("pam_authenticate",pamh,PAM_SYSTEM_ERR);
     retval = _pam_dispatch(pamh, flags, PAM_AUTHENTICATE);
 
-    _pam_sanitize(pamh);
-    _pam_await_timer(pamh, retval);   /* if unsuccessful then wait now */
-
-    D(("pam_authenticate exit"));
+    if (retval != PAM_INCOMPLETE) {
+	_pam_sanitize(pamh);
+	_pam_await_timer(pamh, retval);   /* if unsuccessful then wait now */
+	D(("pam_authenticate exit"));
+    } else {
+	D(("will resume when ready"));
+    }
 
     return retval;
 }
@@ -41,7 +45,7 @@ int pam_setcred(pam_handle_t *pamh, int flags)
 {
     int retval;
 
-    IF_NO_PAMH("pam_setcred",pamh,PAM_SYSTEM_ERR);
+    IF_NO_PAMH("pam_setcred", pamh, PAM_SYSTEM_ERR);
 
     D(("pam_setcred called"));
 
