@@ -62,7 +62,7 @@ int _pam_make_env(pam_handle_t *pamh)
 
     pamh->env = (struct pam_environ *) malloc(sizeof(struct pam_environ));
     if (pamh->env == NULL) {
-	_pam_log_error("_pam_make_env: out of memory");
+	pam_system_log(pamh, NULL, LOG_CRIT, "_pam_make_env: out of memory");
 	return PAM_BUF_ERR;
     }
 
@@ -72,7 +72,8 @@ int _pam_make_env(pam_handle_t *pamh)
 
     pamh->env->list = (char **)calloc( PAM_ENV_CHUNK, sizeof(char *) );
     if (pamh->env->list == NULL) {
-	_pam_log_error("_pam_make_env: no memory for list");
+	pam_system_log(pamh, NULL, LOG_CRIT,
+		       "_pam_make_env: no memory for list");
 	_pam_drop(pamh->env);
 	return PAM_BUF_ERR;
     }
@@ -162,7 +163,8 @@ int pam_putenv(pam_handle_t *pamh, const char *name_value)
     IF_NO_PAMH("pam_putenv", pamh, PAM_ABORT);
 
     if (name_value == NULL) {
-	_pam_log_error("pam_putenv: no variable indicated");
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "pam_putenv: no variable indicated");
 	return PAM_PERM_DENIED;
     }
 
@@ -172,7 +174,7 @@ int pam_putenv(pam_handle_t *pamh, const char *name_value)
 
     for (l2eq=0; name_value[l2eq] && name_value[l2eq] != '='; ++l2eq);
     if (l2eq <= 0) {
-	_pam_log_error("pam_putenv: bad variable");
+	pam_system_log(pamh, NULL, LOG_ERR, "pam_putenv: bad variable");
 	return PAM_BAD_ITEM;
     }
 
@@ -181,8 +183,8 @@ int pam_putenv(pam_handle_t *pamh, const char *name_value)
      */
 
     if (pamh->env == NULL || pamh->env->list == NULL) {
-	_pam_log_error("pam_putenv: no env%s found"
-		     , pamh->env == NULL ? "":"-list" );
+	pam_system_log(pamh, NULL, LOG_ERR, "pam_putenv: no env%s found"
+		       , pamh->env == NULL ? "":"-list");
 	return PAM_ABORT;
     }
 
@@ -204,7 +206,8 @@ int pam_putenv(pam_handle_t *pamh, const char *name_value)
 				     , sizeof(char *) );
 		if (tmp == NULL) {
 		    /* nothing has changed - old env intact */
-		    _pam_log_error("pam_putenv: cannot grow environment");
+		    pam_system_log(pamh, NULL, LOG_CRIT,
+				   "pam_putenv: cannot grow environment");
 		    return PAM_BUF_ERR;
 		}
 
@@ -255,8 +258,9 @@ int pam_putenv(pam_handle_t *pamh, const char *name_value)
     /* getting to here implies we are deleting an item */
 
     if (item < 0) {
-	_pam_log_error("pam_putenv: delete non-existent entry; %s"
-		       , name_value);
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "pam_putenv: delete non-existent entry; %s",
+		       name_value);
 	return PAM_BAD_ITEM;
     }
 
@@ -294,13 +298,14 @@ const char *pam_getenv(pam_handle_t *pamh, const char *name)
     IF_NO_PAMH("pam_getenv", pamh, NULL);
 
     if (name == NULL) {
-	_pam_log_error("pam_getenv: no variable indicated");
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "pam_getenv: no variable indicated");
 	return NULL;
     }
 
     if (pamh->env == NULL || pamh->env->list == NULL) {
-	_pam_log_error("pam_getenv: no env%s found"
-		     , pamh->env == NULL ? "":"-list" );
+	pam_system_log(pamh, NULL, LOG_ERR, "pam_getenv: no env%s found",
+		       pamh->env == NULL ? "":"-list" );
 	return NULL;
     }
 
@@ -366,22 +371,25 @@ char **pam_getenvlist(pam_handle_t *pamh)
     IF_NO_PAMH("pam_getenvlist", pamh, NULL);
 
     if (pamh->env == NULL || pamh->env->list == NULL) {
-	_pam_log_error("pam_getenvlist: no env%s found"
-		       , pamh->env == NULL ? "":"-list" );
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "pam_getenvlist: no env%s found",
+		       pamh->env == NULL ? "":"-list" );
 	return NULL;
     }
 
     /* some quick checks */
 
     if (pamh->env->requested > pamh->env->entries) {
-	_pam_log_error("pam_getenvlist: environment corruption");
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "pam_getenvlist: environment corruption");
 	_pam_dump_env(pamh);                 /* only active when debugging */
 	return NULL;
     }
 
     for (i=pamh->env->requested-1; i-- > 0; ) {
 	if (pamh->env->list[i] == NULL) {
-	    _pam_log_error("pam_getenvlist: environment broken");
+	    pam_system_log(pamh, NULL, LOG_ERR,
+			   "pam_getenvlist: environment broken");
 	    _pam_dump_env(pamh);              /* only active when debugging */
 	    return NULL;          /* somehow we've broken the environment!? */
 	}
