@@ -110,7 +110,8 @@ static int _pam_parse_conf_file(pam_handle_t *pamh, FILE *f
 	    } else {
 		/* Illegal module type */
 		D(("_pam_init_handlers: bad module type: %s", tok));
-		_pam_log_error("(%s) illegal module type: %s"
+		pam_system_log(pamh, NULL, LOG_ERR,
+			       "(%s) illegal module type: %s"
 			       , this_service, tok);
 		module_type = PAM_T_AUTH;                  /* most sensitive */
 		must_fail = 1; /* install as normal but fail when dispatched */
@@ -161,7 +162,8 @@ static int _pam_parse_conf_file(pam_handle_t *pamh, FILE *f
 	    } else {
 		/* no module name given */
 		D(("_pam_init_handlers: no module name supplied"));
-		_pam_log_error("(%s) no module name supplied", this_service);
+		pam_system_log(pamh, NULL, LOG_ERR,
+			       "(%s) no module name supplied", this_service);
 		mod_path = NULL;
 		must_fail = 1;
 	    }
@@ -205,7 +207,8 @@ static int _pam_parse_conf_file(pam_handle_t *pamh, FILE *f
 				   , module_type, actions, mod_path
 				   , argc, argv, argvlen);
 	    if (res != PAM_SUCCESS) {
-		_pam_log_error("error loading %s", mod_path);
+		pam_system_log(pamh, NULL, LOG_ERR,
+			       "error loading %s", mod_path);
 		D(("failed to load module - aborting"));
 		return PAM_ABORT;
 	    }
@@ -237,7 +240,8 @@ int _pam_init_handlers(pam_handle_t *pamh)
     if (! pamh->handlers.module) {
 	if ((pamh->handlers.module =
 	     malloc(MODULE_CHUNK * sizeof(struct loaded_module))) == NULL) {
-	    _pam_log_error("_pam_init_handlers: no memory loading module");
+	    pam_system_log(pamh, NULL, LOG_CRIT,
+			   "_pam_init_handlers: no memory loading module");
 	    return PAM_BUF_ERR;
 	}
 	pamh->handlers.modules_allocated = MODULE_CHUNK;
@@ -254,8 +258,9 @@ int _pam_init_handlers(pam_handle_t *pamh)
 	 int fd_tmp;
 
 	 if ((fd_tmp = open( PAM_LOCK_FILE, O_RDONLY )) != -1) {
-	      _pam_log_error("_pam_init_handlers: PAM lockfile ("
-			     PAM_LOCK_FILE ") exists - aborting");
+	     pam_system_log(pamh, NULL, LOG_ERR,
+			    "_pam_init_handlers: PAM lockfile ("
+			    PAM_LOCK_FILE ") exists - aborting");
 	      (void) close(fd_tmp);
 	      /*
 	       * to avoid swamping the system with requests
@@ -284,8 +289,9 @@ int _pam_init_handlers(pam_handle_t *pamh)
 	    filename = malloc(sizeof(PAM_CONFIG_DF)
 			      +strlen(pamh->service_name));
 	    if (filename == NULL) {
-		_pam_log_error("_pam_init_handlers: no memory; service %s"
-			       , pamh->service_name);
+		pam_system_log(pamh, NULL, LOG_ERR,
+			       "_pam_init_handlers: no memory; service %s",
+			       pamh->service_name);
 		return PAM_BUF_ERR;
 	    }
 	    sprintf(filename, PAM_CONFIG_DF, pamh->service_name);
@@ -300,10 +306,12 @@ int _pam_init_handlers(pam_handle_t *pamh)
 		    );
 		fclose(f);
 		if (retval != PAM_SUCCESS) {
-		    _pam_log_error("_pam_init_handlers: error reading %s"
-				   , filename);
-		    _pam_log_error("_pam_init_handlers: [%s]"
-				   , pam_strerror(pamh, retval));
+		    pam_system_log(pamh, NULL, LOG_ERR,
+				   "_pam_init_handlers: error reading %s",
+				   filename);
+		    pam_system_log(pamh, NULL, LOG_ERR,
+				   "_pam_init_handlers: [%s]",
+				   pam_strerror(pamh, retval));
 		} else {
 		    read_something = 1;
 		}
@@ -340,17 +348,20 @@ int _pam_init_handlers(pam_handle_t *pamh)
 			);
 		    fclose(f);
 		    if (retval != PAM_SUCCESS) {
-			_pam_log_error("_pam_init_handlers: error reading %s"
-				       , PAM_DEFAULT_SERVICE_FILE);
-			_pam_log_error("_pam_init_handlers: [%s]"
-				       , pam_strerror(pamh, retval));
+			pam_system_log(pamh, NULL, LOG_ERR,
+				       "_pam_init_handlers: error reading %s",
+				       PAM_DEFAULT_SERVICE_FILE);
+			pam_system_log(pamh, NULL, LOG_ERR,
+				       "_pam_init_handlers: [%s]",
+				       pam_strerror(pamh, retval));
 		    } else {
 			read_something = 1;
 		    }
 		} else {
 		    D(("unable to open %s", PAM_DEFAULT_SERVICE_FILE));
-		    _pam_log_error("_pam_init_handlers: no default config %s"
-				   , PAM_DEFAULT_SERVICE_FILE);
+		    pam_system_log(pamh, NULL, LOG_ERR,
+				   "_pam_init_handlers: no default config %s",
+				   PAM_DEFAULT_SERVICE_FILE);
 		}
 		if (!read_something) {          /* nothing read successfully */
 		    retval = PAM_ABORT;
@@ -358,7 +369,8 @@ int _pam_init_handlers(pam_handle_t *pamh)
 	    }
 	} else {
 	    if ((f = fopen(PAM_CONFIG, "r")) == NULL) {
-		_pam_log_error("_pam_init_handlers: could not open "
+		pam_system_log(pamh, NULL, LOG_ERR,
+			       "_pam_init_handlers: could not open "
 			       PAM_CONFIG );
 		return PAM_ABORT;
 	    }
@@ -376,7 +388,8 @@ int _pam_init_handlers(pam_handle_t *pamh)
 
     if (retval != PAM_SUCCESS) {
 	/* Read error */
-	_pam_log_error("error reading PAM configuration file");
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "error reading PAM configuration file");
 	return PAM_ABORT;
     }
 
@@ -520,7 +533,8 @@ int _pam_add_handler(pam_handle_t *pamh
                                *sizeof(struct loaded_module));
 	    if (tmp == NULL) {
 		D(("cannot enlarge module pointer memory"));
-		_pam_log_error("realloc returned NULL in _pam_add_handler");
+		pam_system_log(pamh, NULL, LOG_ERR,
+			       "realloc returned NULL in _pam_add_handler");
 		_pam_drop(mod_full_path);
 		return PAM_ABORT;
 	    }
@@ -542,9 +556,10 @@ int _pam_add_handler(pam_handle_t *pamh
 	D(("_pam_add_handler: dlopen'ed"));
 	if (mod->dl_handle == NULL) {
 	    D(("_pam_add_handler: dlopen(%s) failed", mod_path));
-	    _pam_log_error("unable to dlopen(%s)", mod_path);
+	    pam_system_log(pamh, NULL, LOG_ERR, "unable to dlopen(%s)",
+			   mod_path);
 # ifndef PAM_SHL
-	    _pam_log_error("[dlerror: %s]", dlerror());
+	    pam_system_log(pamh, NULL, LOG_ERR, "[dlerror: %s]", dlerror());
 # endif /* PAM_SHL */
 	    /* Don't abort yet; static code may be able to find function.
 	     * But defaults to abort if nothing found below... */
@@ -564,7 +579,8 @@ int _pam_add_handler(pam_handle_t *pamh
 	    if (mod->dl_handle == NULL) {
 	        D(("_pam_add_handler: unable to find static handler %s",
 		   mod_path));
-		_pam_log_error("unable to open static handler %s", mod_path);
+		pam_system_log(pamh, NULL, LOG_ERR,
+			       "unable to open static handler %s", mod_path);
 		/* Didn't find module in dynamic or static..will mark bad */
 	    } else {
 	        D(("static module added successfully"));
@@ -579,14 +595,16 @@ int _pam_add_handler(pam_handle_t *pamh
 	    mod->dl_handle = NULL;
 	    mod->type = PAM_MT_FAULTY_MOD;
 	    pamh->handlers.modules_used++;
-	    _pam_log_error("adding faulty module: %s", mod_path);
+	    pam_system_log(pamh, NULL, LOG_ERR,
+			   "adding faulty module: %s", mod_path);
 	    success = PAM_SUCCESS;  /* We have successfully added a module */
 	}
 
 	/* indicate its name - later we will search for it by this */
 	if ((mod->name = _pam_strdup(mod_path)) == NULL) {
 	    D(("_pam_handler: couldn't get memory for mod_path"));
-	    _pam_log_error("no memory for module path", mod_path);
+	    pam_system_log(pamh, NULL, LOG_ERR,
+			   "no memory for module path", mod_path);
 	    success = PAM_ABORT;
 	}
 
@@ -675,8 +693,9 @@ int _pam_add_handler(pam_handle_t *pamh
 	 mod->type != PAM_MT_FAULTY_MOD
 	) {
 	D(("_pam_add_handlers: illegal module library type; %d", mod->type));
-	_pam_log_error("internal error: module library type not known: %s;%d"
-		       , sym, mod->type);
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "internal error: module library type not known: %s;%d",
+		       sym, mod->type);
 	return PAM_ABORT;
     }
 
@@ -691,13 +710,15 @@ int _pam_add_handler(pam_handle_t *pamh
         (func = (servicefn) dlsym(mod->dl_handle, sym)) == NULL
 # endif /* PAM_SHL */
 	) {
-	_pam_log_error("unable to resolve symbol: %s", sym);
+	pam_system_log(pamh, NULL, LOG_ERR, "unable to resolve symbol: %s",
+		       sym);
     }
 #endif
 #ifdef PAM_STATIC
     if ((mod->type == PAM_MT_STATIC_MOD) &&
         (func = (servicefn)_pam_get_static_sym(mod->dl_handle, sym)) == NULL) {
-	_pam_log_error("unable to resolve static symbol: %s", sym);
+	pam_system_log(pamh, NULL, LOG_ERR,
+		       "unable to resolve static symbol: %s", sym);
     }
 #endif
     if (sym2) {
@@ -710,14 +731,16 @@ int _pam_add_handler(pam_handle_t *pamh
 	    (func2 = (servicefn) dlsym(mod->dl_handle, sym2)) == NULL
 # endif /* PAM_SHL */
 	    ) {
-	    _pam_log_error("unable to resolve symbol: %s", sym2);
+	    pam_system_log(pamh, NULL, LOG_ERR, "unable to resolve symbol: %s",
+			   sym2);
 	}
 #endif
 #ifdef PAM_STATIC
 	if ((mod->type == PAM_MT_STATIC_MOD) &&
 	    (func2 = (servicefn)_pam_get_static_sym(mod->dl_handle, sym2))
 	    == NULL) {
-	    _pam_log_error("unable to resolve symbol: %s", sym2);
+	    pam_system_log(pamh, NULL, LOG_ERR, "unable to resolve symbol: %s",
+			   sym2);
 	}
 #endif
     }
@@ -730,7 +753,8 @@ int _pam_add_handler(pam_handle_t *pamh
     }
 
     if ((*handler_p = malloc(sizeof(struct handler))) == NULL) {
-	_pam_log_error("cannot malloc struct handler #1");
+	pam_system_log(pamh, NULL, LOG_CRIT,
+		       "cannot malloc struct handler #1");
 	return (PAM_ABORT);
     }
 
@@ -749,7 +773,8 @@ int _pam_add_handler(pam_handle_t *pamh
 	}
 
 	if ((*handler_p2 = malloc(sizeof(struct handler))) == NULL) {
-	    _pam_log_error("cannot malloc struct handler #2");
+	    pam_system_log(pamh, NULL, LOG_CRIT,
+			   "cannot malloc struct handler #2");
 	    return (PAM_ABORT);
 	}
 
@@ -759,7 +784,8 @@ int _pam_add_handler(pam_handle_t *pamh
 	(*handler_p2)->argc = argc;
 	if (argv) {
 	    if (((*handler_p2)->argv = malloc(argvlen)) == NULL) {
-		_pam_log_error("cannot malloc argv for handler #2");
+		pam_system_log(pamh, NULL, LOG_CRIT,
+			       "cannot malloc argv for handler #2");
 		return (PAM_ABORT);
 	    }
 	    memcpy((*handler_p2)->argv, argv, argvlen);
