@@ -10,30 +10,16 @@
  * Please see end of file for copyright.
  *
  * Creator: Marc Ewing.
+ * Maintained: AGM
  * 
  * $Log: pam_private.h,v $
- * Revision 1.12  1997/04/05 06:57:37  morgan
- * added sanitize prototype
- *
- * Revision 1.11  1997/02/15 16:01:21  morgan
- * update version and #defines for /etc/pam.d/ code
- *
- * Revision 1.10  1997/01/04 20:09:27  morgan
- * update for .55
- * added "faulty module" token
- *
- * Revision 1.9  1996/12/18 04:24:04  morgan
- * logging prior to bad pam.conf entry handling
- *
- * Revision 1.8  1996/12/01 03:14:13  morgan
- * use _pam_macros.h
  */
 
 #ifndef _PAM_PRIVATE_H
 #define _PAM_PRIVATE_H
 
 /* this is not used at the moment --- AGM */
-#define LIBPAM_VERSION 59
+#define LIBPAM_VERSION 65
 
 #include <security/pam_appl.h>
 #include <security/pam_modules.h>
@@ -91,8 +77,8 @@ struct service {
     int modules_used;
     int handlers_loaded;
 
-    struct handlers conf;        /* the configured handlers -- AGM */
-    struct handlers other;       /* the default handlers    -- AGM */
+    struct handlers conf;        /* the configured handlers */
+    struct handlers other;       /* the default handlers */
 };
 
 /*
@@ -115,34 +101,56 @@ struct pam_environ {
 typedef enum { PAM_FALSE, PAM_TRUE } _pam_boolean;
 
 struct _pam_fail_delay {
-     _pam_boolean set;
-     unsigned int delay;
-     time_t begin;
+    _pam_boolean set;
+    unsigned int delay;
+    time_t begin;
+    const void *delay_fn_ptr;
+};
+
+struct _pam_former_state {
+/* this is known and set by _pam_dispatch() */
+    int choice;            /* which flavor of module function did we call? */
+
+/* state info for the _pam_dispatch_aux() function */
+    int depth;             /* how deep in the stack were we? */
+    int impression;        /* the impression at that time */
+    int status;            /* the status before returning incomplete */
+
+/* state info used by pam_get_user() function */
+    int want_user;
+    char *prompt;          /* saved prompt information */
+
+/* state info for the pam_chauthtok() function */
+    _pam_boolean update;
 };
 
 struct pam_handle {
+    char *authtok;
+    struct pam_conv *pam_conversation;
+    char *oldauthtok;
+    char *prompt;                /* for use by pam_get_user() */
     char *service_name;
     char *user;
-    char *prompt;                /* for use by pam_get_user() -- AGM */
-    char *tty;
     char *rhost;
     char *ruser;
-    char *authtok;
-    char *oldauthtok;
-    struct pam_conv *pam_conversation;
+    char *tty;
+    struct pam_log_state pam_default_log;      /* for ident etc., log state */
     struct pam_data *data;
     struct pam_environ *env;      /* structure to maintain environment list */
     struct _pam_fail_delay fail_delay;   /* helper function for easy delays */
     struct service handlers;
+    struct _pam_former_state former;  /* library state - support for
+					 event driven applications */
 };
 
 /* Values for select arg to _pam_dispatch() */
-#define PAM_AUTHENTICATE  0
-#define PAM_SETCRED       1
-#define PAM_ACCOUNT       2
-#define PAM_OPEN_SESSION  3
-#define PAM_CLOSE_SESSION 4
-#define PAM_CHAUTHTOK     5
+#define PAM_NOT_STACKED   0
+#define PAM_AUTHENTICATE  1
+#define PAM_SETCRED       2
+#define PAM_ACCOUNT       3
+#define PAM_OPEN_SESSION  4
+#define PAM_CLOSE_SESSION 5
+#define PAM_CHAUTHTOK     6
 
 #define _PAM_ACTION_IS_JUMP(x)  ((x) > 0)
 #define _PAM_ACTION_IGNORE      0
@@ -153,7 +161,8 @@ struct pam_handle {
 #define _PAM_ACTION_RESET      -5
 /* Add any new entries here.  Will need to change ..._UNDEF and then
  * need to change pam_tokens.h */
-#define _PAM_ACTION_UNDEF      -6      /* this is treated as an error (==-3) */
+#define _PAM_ACTION_UNDEF      -6   /* this is treated as an error
+				       ( = _PAM_ACTION_BAD) */
 
 /* character tables for parsing config files */
 extern const char * const _pam_token_actions[-_PAM_ACTION_UNDEF];
@@ -201,6 +210,7 @@ void _pam_await_timer(pam_handle_t *pamh, int status);
 
 #endif /* LINUX_PAM */
 
+typedef void (*voidfunc(void))(void);
 #ifdef PAM_STATIC
 
 /* The next two in ../modules/_pam_static/pam_static.c */
@@ -210,7 +220,6 @@ struct pam_module * _pam_open_static_handler(char *path);
 
 /* Return pointer to function requested from static module */
 
-typedef void (*voidfunc(void))(void);
 voidfunc *_pam_get_static_sym(struct pam_module *mod, const char *symname);
 
 #endif
@@ -235,8 +244,6 @@ char *_pam_strdup(const char *s);
 
 int _pam_mkargv(char *s, char ***argv, int *argc);
 
-void _pam_log_error(const char *format, ...);
-
 void _pam_sanitize(pam_handle_t *pamh);
 
 void _pam_set_default_control(int *control_array, int default_action);
@@ -248,16 +255,26 @@ void _pam_parse_control(int *control_array, char *tok);
  *       else
  */
 
-#define IF_NO_PAMH(X,pamh,ERR) \
-if ((pamh) == NULL) { \
-    _pam_log_error(X ": NULL pam handle passed"); \
-    return ERR; \
+#define IF_NO_PAMH(X,pamh,ERR)                    \
+if ((pamh) == NULL) {                             \
+    pam_system_log(NULL, NULL, LOG_ERR, X ": NULL pam handle passed"); \
+    return ERR;                                   \
 }
 
 /* Definition for the default username prompt used by pam_get_user() */
 
 #define PAM_DEFAULT_PROMPT "Please enter username: "
 
+/*
+ * pam_system_log default ident/facility..
+ */
+
+#define PAM_LOG_STATE_DEFAULT {      \
+    PAM_LOG_STATE_IDENT,     \
+    PAM_LOG_STATE_OPTION,    \
+    PAM_LOG_STATE_FACILITY   \
+}
+
 /*
  * include some helpful macros
  */
@@ -266,7 +283,7 @@ if ((pamh) == NULL) { \
 
 /*
  * Copyright (C) 1995 by Red Hat Software, Marc Ewing
- * Copyright (c) 1996, Andrew G. Morgan <morgan@parc.power.net>
+ * Copyright (c) 1996-8, Andrew G. Morgan <morgan@linux.kernel.org>
  *
  * All rights reserved
  *
