@@ -604,7 +604,7 @@ pam_ruserok (pam_handle_t *pamh,
 
         /* loop though address list */
         for (n = 0; hp->h_addr_list[n]; n++);
-        D(("rhosts: %d addresses", n))
+        D(("rhosts: %d addresses", n));
 
         if (n) {
             addrs = calloc (n, hp->h_length);
@@ -612,7 +612,7 @@ pam_ruserok (pam_handle_t *pamh,
                 memcpy (addrs+i, hp->h_addr_list[i], hp->h_length);
 
             for (i = 0; i < n && answer; i++) {
-                D(("rhosts: address %d is %04x", i, addrs[i]))
+                D(("rhosts: address %d is %04x", i, addrs[i]));
                 answer = pam_iruserok(pamh, opts, addrs[i], superuser,
 				      ruser, luser, rhost);
                          /* answer == 0 means success */
