@@ -11,8 +11,10 @@
  * Stuff stolen from pam_rootok and pam_listfile
  */
 
-#define _GNU_SOURCE
-#include <features.h>
+#ifdef linux
+# define _GNU_SOURCE
+# include <features.h>
+#endif
 
 #include <stdio.h>
 #include <strings.h>
@@ -23,6 +25,7 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <sys/param.h>
 
 #ifndef TRUE
 #define TRUE  1L
@@ -60,6 +63,10 @@ enum TALLY_RESET {
 
 #define UID_FMT    "%hu"
 
+#ifndef FILENAME_MAX
+# define FILENAME_MAX MAXPATHLEN
+#endif
+
 /*---------------------------------------------------------------------*/
 
 /* some syslogging */
@@ -476,7 +483,7 @@ PAM_FUNCTION( pam_sm_acct_mgmt ) {
 
 /* static module data */
 
-struct pam_module _pam_listfile_modstruct = {
+struct pam_module _pam_tally_modstruct = {
      MODULE_NAME,
 #ifdef PAM_SM_AUTH
      pam_sm_authenticate,
